fn to_snafu(n: i64) -> String
Convert from decimal by first finding the result modulo 5 for each digit. If the answer is 3 or 4 then we must add a carry to the next digit to account for the subtraction.